vip\_hci.fits package
=====================

Submodules
----------

vip\_hci.fits.fits module
-------------------------

.. automodule:: vip_hci.fits.fits
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.fits.headers module
----------------------------

.. automodule:: vip_hci.fits.headers
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: vip_hci.fits
   :members:
   :undoc-members:
   :show-inheritance:
